@@ -229,7 +229,6 @@ public class LocaleNames_gsw extends OpenListResourceBundle {
             { "IL", "Israel" },
             { "IM", "Insle vo M\u00e4n" },
             { "IN", "Indie" },
-            { "IO", "Britischs Territoorium im Indische Oozean" },
             { "IQ", "Iraak" },
             { "IR", "Iraan" },
             { "IS", "Iisland" },
@@ -964,7 +963,6 @@ public class LocaleNames_gsw extends OpenListResourceBundle {
             { "type.co.pinyin", "Pinyin-Sortiirregle" },
             { "type.co.stroke", "Strichfolg" },
             { "type.ca.chinese", "Chineesisch Kal\u00e4nder" },
-            { "type.ca.islamic", "Islaamisch Kal\u00e4nder" },
             { "type.co.big5han", "Tradizionells Chineesisch - Big5" },
             { "type.ca.buddhist", "Buddhischtisch Kal\u00e4nder" },
             { "type.ca.japanese", "Japaanisch Kal\u00e4nder" },
@@ -972,7 +970,6 @@ public class LocaleNames_gsw extends OpenListResourceBundle {
             { "type.co.gb2312han", "Ver\u00e4ifachts Chineesisch - GB2312" },
             { "type.co.phonebook", "Telifonbuech-Sortiirregle" },
             { "type.co.traditional", "Tradizionelli Sortiir-Regle" },
-            { "type.ca.islamic-civil", "B\u00fcrgerlich islaamisch Kal\u00e4nder" },
         };
         return data;
     }
